<?php
/**
 * A command for registration handling
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class WebShipsimuRegisterCommand extends BaseCommand implements Commandable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Clean up a little
		$this->removeNumberFormaters();
		$this->removeSystemArray();
	}

	/**
	 * Creates an instance of this command and sets the resolver instance
	 *
	 * @param	$resolverInstance	An instance of a command resolver
	 * @return	$commandInstance	The created command instance
	 */
	public final static function createWebShipsimuRegisterCommand (CommandResolver $resolverInstance) {
		// Get a new instance
		$commandInstance = new WebShipsimuRegisterCommand();

		// Set the resolver instance
		$commandInstance->setResolverInstance($resolverInstance);

		// Return the prepared instance
		return $commandInstance;
	}

	/**
	 * Executes the command with given request and response objects
	 *
	 * @param	$requestInstance	An instance of a class with an Requestable interface
	 * @param	$responseInstance	An instance of a class with an Responseable interface
	 * @return	void
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		// First get a UserRegistration instance
		$registerInstance = ObjectFactory::createObjectByConfiguredName('user_registration_class');

		// First set request and response instance
		$registerInstance->setRequestInstance($requestInstance);
		$registerInstance->setResponseInstance($responseInstance);

		// Encrypt the password
		$registerInstance->encryptPassword('pass1');

		// Do things before registration
		$registerInstance->doPreRegistration();

		// Register the new user
		$registerInstance->registerNewUser();

		// Do things after registration like notifying partner pages or queueing
		// them for notification
		$registerInstance->doPostRegistration();

		// Redirect or login after registration
		$registerInstance->doPostAction();
	}

	/**
	 * Adds extra filters to the given controller instance
	 *
	 * @param	$controllerInstance		A controller instance
	 * @param	$requestInstance		An instance of a class with an Requestable interface
	 * @return	void
	 * @todo	Add some more pre/post filters to the controller
	 */
	public function addExtraFilters (Controller $controllerInstance, Requestable $requestInstance) {
		// Validate email address (if configured: check on double email addresses)
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('email_validator_class'));

		// Validate username and check if it does not exist
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('username_validator_class'));

		// Validate if username is "guest" and not taken
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('username_is_guest_class'));

		// Validate if password is set
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('password_validator_class'));

		// Check if rules where accepted
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('rules_accepted_class'));

		// Validate CAPTCHA input
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('captcha_register_verifier_class'));
	}
}

// [EOF]
?>
